==> qore-1.19.2.tar.bz2: qore-1.19.2/docs/modules/OracleSqlUtilBase/html/navtreedata.js <==
/*
 @licstart  The following is the entire license notice for the JavaScript code in this file.

 The MIT License (MIT)

 Copyright (C) 1997-2020 by Dimitri van Heesch

 Permission is hereby granted, free of charge, to any person obtaining a copy of this software
 and associated documentation files (the "Software"), to deal in the Software without restriction,
 including without limitation the rights to use, copy, modify, merge, publish, distribute,
 sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all copies or
 substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
 BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

 @licend  The above is the entire license notice for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "Qore OracleSqlUtilBase Module Reference", "index.html", [
    [ "OracleSqlUtilBase Module", "index.html", [
      [ "OracleSqlUtilBase Module Introduction", "index.html#oraclesqlutilbaseintro", null ],
      [ "SQL Operations on Oracle", "index.html#ora_sql_operations", [
        [ "Select With Paging on Oracle", "index.html#ora_paging", null ],
        [ "IN Operator on Oracle", "index.html#ora_in_operator", null ],
        [ "Partition Support in Selects", "index.html#ora_partitioning_select", null ],
        [ "Partition Support in Joins", "index.html#ora_partitioning_join", null ]
      ] ],
      [ "Schema Management on Oracle", "index.html#ora_schema_management", [
        [ "Type Mapping", "index.html#ora_type_mapping", null ],
        [ "Additional Object Types Supported", "index.html#ora_other_objects", null ],
        [ "Materialized Views", "index.html#ora_materialized_views", null ],
        [ "Packages", "index.html#ora_packages", null ],
        [ "Types", "index.html#ora_types", null ]
      ] ],
      [ "Release Notes", "index.html#ora_relnotes", [
        [ "OracleSqlUtilBase v1.6", "index.html#oracle16", null ],
        [ "OracleSqlUtilBase v1.5", "index.html#oracle15", null ],
        [ "OracleSqlUtilBase v1.4.4", "index.html#oracle144", null ],
        [ "OracleSqlUtilBase v1.4.3", "index.html#oraclev143", null ],
        [ "OracleSqlUtilBase v1.4.2", "index.html#v142", null ],
        [ "OracleSqlUtilBase v1.4.1", "index.html#v141", null ],
        [ "OracleSqlUtilBase v1.4", "index.html#v14", null ],
        [ "OracleSqlUtilBase v1.3.1", "index.html#v131", null ],
        [ "OracleSqlUtilBase v1.3", "index.html#v13", null ],
        [ "OracleSqlUtilBase v1.2.5", "index.html#v125", null ],
        [ "OracleSqlUtilBase v1.2.4", "index.html#v124", null ],
        [ "OracleSqlUtilBase v1.2.3", "index.html#v123", null ],
        [ "OracleSqlUtilBase v1.2.2", "index.html#v122", null ],
        [ "OracleSqlUtilBase v1.2.1", "index.html#v121", null ],
        [ "OracleSqlUtilBase v1.2", "index.html#v12", null ],
        [ "OracleSqlUtilBase v1.1", "index.html#v11", null ],
        [ "OracleSqlUtilBase v1.0", "index.html#v10", null ]
      ] ]
    ] ],
    [ "Namespaces", "namespaces.html", [
      [ "Namespace List", "namespaces.html", "namespaces_dup" ],
      [ "Namespace Members", "namespacemembers.html", [
        [ "All", "namespacemembers.html", null ],
        [ "Functions", "namespacemembers_func.html", null ]
      ] ]
    ] ],
    [ "Classes", "annotated.html", [
      [ "Class List", "annotated.html", "annotated_dup" ],
      [ "Class Index", "classes.html", null ],
      [ "Class Hierarchy", "hierarchy.html", "hierarchy" ],
      [ "Class Members", "functions.html", [
        [ "All", "functions.html", null ],
        [ "Functions", "functions_func.html", null ],
        [ "Variables", "functions_vars.html", null ]
      ] ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"annotated.html"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';

==> qore-2.0.0.tar.bz2: qore-2.0.0/docs/modules/OracleSqlUtilBase/html/navtreedata.js <==
/*
 @licstart  The following is the entire license notice for the JavaScript code in this file.

 The MIT License (MIT)

 Copyright (C) 1997-2020 by Dimitri van Heesch

 Permission is hereby granted, free of charge, to any person obtaining a copy of this software
 and associated documentation files (the "Software"), to deal in the Software without restriction,
 including without limitation the rights to use, copy, modify, merge, publish, distribute,
 sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all copies or
 substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
 BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

 @licend  The above is the entire license notice for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "Qore OracleSqlUtilBase Module Reference", "index.html", [
    [ "OracleSqlUtilBase Module", "index.html", "index" ],
    [ "Namespaces", "namespaces.html", [
      [ "Namespace List", "namespaces.html", "namespaces_dup" ],
      [ "Namespace Members", "namespacemembers.html", [
        [ "All", "namespacemembers.html", null ],
        [ "Functions", "namespacemembers_func.html", null ]
      ] ]
    ] ],
    [ "Classes", "annotated.html", [
      [ "Class List", "annotated.html", "annotated_dup" ],
      [ "Class Index", "classes.html", null ],
      [ "Class Hierarchy", "hierarchy.html", "hierarchy" ],
      [ "Class Members", "functions.html", [
        [ "All", "functions.html", null ],
        [ "Functions", "functions_func.html", null ],
        [ "Variables", "functions_vars.html", null ]
      ] ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"annotated.html",
"class_oracle_sql_util_base_1_1_oracle_table.html#a30fa5809a510c9b00a5241a73a8e82c6"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';
